"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = require("./index");
const chai_1 = require("chai");
describe('empty results', function () {
    it('should return an empty string when pattern and source are empty', function () {
        (0, chai_1.expect)((0, index_1.patternize)('', '')).to.equal('');
    });
    it('should return an empty string for any source when pattern is empty', function () {
        (0, chai_1.expect)((0, index_1.patternize)('', 'asdf-+.123xoASDF')).to.equal('');
    });
    it('should return an empty string for any pattern not containing fixed characters when source is empty', function () {
        (0, chai_1.expect)((0, index_1.patternize)('aaddA-.*da', '')).to.equal('');
    });
});
describe('single character tests', function () {
    it('should return the source digits', function () {
        const source = '012';
        (0, chai_1.expect)((0, index_1.patternize)('ddd', source)).to.equal(source);
    });
    it('should return the source letters without changing case', function () {
        const source = 'AbcD';
        (0, chai_1.expect)((0, index_1.patternize)('____', source)).to.equal(source);
    });
    it('should return the source symbols', function () {
        const source = '-+/';
        (0, chai_1.expect)((0, index_1.patternize)('***', source)).to.equal(source);
    });
    it('should return any characters in the source', function () {
        const source = 'a+2*D';
        (0, chai_1.expect)((0, index_1.patternize)('.....', source)).to.equal(source);
    });
    it('should return the characters in the pattern', function () {
        const pattern = 'g#X2';
        (0, chai_1.expect)((0, index_1.patternize)(pattern, '')).to.equal(pattern);
    });
    it('should return the escaped characters in the pattern', function () {
        (0, chai_1.expect)((0, index_1.patternize)('\\.\\*\\a', '')).to.equal('.*a');
    });
});
describe('basic modification tests', function () {
    it('should remove non-matching characters', function () {
        (0, chai_1.expect)((0, index_1.patternize)('dddaaa', '12abc3d45ef6')).to.equal('123def');
    });
    it('should truncate the source to the pattern\'s length', function () {
        (0, chai_1.expect)((0, index_1.patternize)('___', 'abcdef')).to.equal('abc');
    });
    it('should add missing fixed characters', function () {
        (0, chai_1.expect)((0, index_1.patternize)('"___"\\+dd="___dd"', 'abc12abc12')).to.equal('"abc"+12="abc12"');
    });
    it('should change the source letters\' case to match the pattern', function () {
        (0, chai_1.expect)((0, index_1.patternize)('AaaaAaaa', 'testCASE')).to.equal('TestCase');
    });
    it('should output repeating character types', function () {
        (0, chai_1.expect)((0, index_1.patternize)('d+\\.a+', '1234abcd')).to.equal('1234.abcd');
    });
});
describe('invalid pattern tests', function () {
    it('should throw if the pattern starts with a \'+\' (repetition)', function () {
        (0, chai_1.expect)(() => { (0, index_1.patternize)('+aaa', '123asd'); }).to.throw();
    });
});
describe('specific pattern tests', function () {
    it('should convert the source string to US phone number format', function () {
        (0, chai_1.expect)((0, index_1.patternize)('(ddd) ddd dddd', '5551234567')).to.equal('(555) 123 4567');
    });
    it('should convert the source string to IPv4 format', function () {
        (0, chai_1.expect)((0, index_1.patternize)('ddd\\.ddd\\.ddd\\.ddd', '123123123123')).to.equal('123.123.123.123');
    });
    it('should convert any two-part string into a "Firstname Lastname" form', () => {
        (0, chai_1.expect)((0, index_1.patternize)('Aa+ Aa+', 'lowercase fullname')).to.equal('Lowercase Fullname');
    });
});
